@@ -1,9 +1,8 @@
 package Test::Smoke::Patcher;
 use strict;
 
-# $Id$
 use vars qw( $VERSION @EXPORT );
-$VERSION = '0.011';
+$VERSION = '0.012';
 
 use base 'Exporter';
 use File::Spec;
@@ -13,7 +12,9 @@ use Test::Smoke::Util qw( get_regen_headers );
 
 @EXPORT = qw( &TRY_REGEN_HEADERS );
 
-sub TRY_REGEN_HEADERS() { 1 }
+sub MAX_FLAG_COUNT    () { 16 }
+sub ALL_FLAGS         () { (2**MAX_FLAG_COUNT) - 1 }
+sub TRY_REGEN_HEADERS () { 1 }
 
 my %CONFIG = (
     df_ddir     => File::Spec->rel2abs( cwd ),
@@ -21,13 +22,14 @@ my %CONFIG = (
     df_pfile    => undef,
     df_patchbin => 'patch',
     df_popts    => '',       # '-p1' is added in call_patch()
-    df_flags    => 1,
+    df_flags    => 0,
+    df_regen    => 1,        # regen => set/unset TRY_REGEN_HEADERS in flags
     df_oldpatch => 0,
     df_v        => 0,
 
     valid_type => { single => 1, multi => 1 },
-    single     => [qw( pfile patchbin popts flags oldpatch )],
-    multi      => [qw( pfile patchbin popts flags oldpatch )],
+    single     => [qw( pfile patchbin popts flags regen oldpatch )],
+    multi      => [qw( pfile patchbin popts flags regen oldpatch )],
 );
 
 =head1 NAME
@@ -66,7 +68,7 @@ There are two ways to initialise the B<Test::Smoke::Patcher> object.
 
 =item B<single> mode
 
-The B<pfile> attribute is a pointer to a I<single> patch. 
+The B<pfile> attribute is a pointer to a I<single> patch.
 There are four (4) ways to specify that patch.
 
 =over 4
@@ -86,7 +88,7 @@ You passed an opened filehandle to a file containing the patch.
 
 =item I<filename>
 
-If none of the above apply, it is assumed you passed a filename. 
+If none of the above apply, it is assumed you passed a filename.
 Relative paths are rooted at the builddir (B<ddir> attribute).
 
 =back
@@ -94,7 +96,7 @@ Relative paths are rooted at the builddir (B<ddir> attribute).
 =item B<multi> mode
 
 The B<pfile> attribute is a pointer to a recource that contains filenames
-of patches. 
+of patches.
 The format of this recource is one filename per line optionally followed
 by a semi-colon (;) and switches for the patch program.
 
@@ -114,6 +116,18 @@ The patch-resource can also be specified in four (4) ways.
 
 =back
 
+=head2 TRY_REGEN_HEADERS
+
+Constant: 1
+
+=head2 MAX_FLAG_COUNT
+
+Constant: 16
+
+=head2 ALL_FLAGS
+
+Constant: 2**MAX_FLAG_COUNT) - 1
+
 =head1 METHODS
 
 =over 4
@@ -130,6 +144,7 @@ Valid keys for C<%args>:
     * pfile:    path to either the patch (single) or a textfile (multi)
     * popts:    options to pass to 'patch' (-p1)
     * patchbin: full path to the patch binary (patch)
+    * regen:    flag to set/unset the TRY_REGEN_HEADERS flag
     * v:        verbosity 0..2
 
 =cut
@@ -156,17 +171,23 @@ sub new {
         my $value = exists $args{$_} ? $args{ $_ } : $CONFIG{ "df_$_" };
         ( $_ => $value )
     } ( v => ddir => fdir => @{ $CONFIG{ $type } } );
-    $fields{pdir} = File::Spec->rel2abs( 
+    $fields{pdir} = File::Spec->rel2abs(
         defined $fields{fdir} ? $fields{fdir} : $fields{ddir}
     );
     $fields{ptype} = $type;
+    if ($fields{regen}) {
+        $fields{flags} = ($fields{flags} | TRY_REGEN_HEADERS) & ALL_FLAGS;
+    }
+    else {
+        $fields{flags} = ($fields{flags} & ~TRY_REGEN_HEADERS) & ALL_FLAGS;
+    }
 
     bless { %fields }, $class;
 }
 
 =item Test::Smoke::Patcher->config( $key[, $value] )
 
-C<config()> is an interface to the package lexical C<%CONFIG>, 
+C<config()> is an interface to the package lexical C<%CONFIG>,
 which holds all the default values for the C<new()> arguments.
 
 With the special key B<all_defaults> this returns a reference
@@ -262,9 +283,9 @@ sub perl_regen_headers {
 
 =item $patcher->patch_single( )
 
-C<patch_single()> checks if the B<pfile> attribute is a plain scalar 
+C<patch_single()> checks if the B<pfile> attribute is a plain scalar
 or a ref to a scalar, array, glob. In the first case this is taken to
-be a filename.  A GLOB-ref is a filehandle, the other two are taken to 
+be a filename.  A GLOB-ref is a filehandle, the other two are taken to
 be literal content.
 
 =cut
@@ -287,7 +308,7 @@ sub patch_single {
         $content = do { local $/; <PATCH> };
         $self->{pfinfo} ||= 'file content';
     } else {
-        my $full_name = File::Spec->file_name_is_absolute( $pfile ) 
+        my $full_name = File::Spec->file_name_is_absolute( $pfile )
             ? $pfile : File::Spec->rel2abs( $pfile, $self->{pdir} );
 
         $self->{pfinfo} = $full_name;
@@ -305,9 +326,9 @@ sub patch_single {
 
 =item $patcher->patch_multi( )
 
-C<patch_multi()> checks the B<pfile> attribute is a plain scalar 
+C<patch_multi()> checks the B<pfile> attribute is a plain scalar
 or a ref to a scalar, array, glob. In the first case this is taken to
-be a filename.  A GLOB-ref is a filehandle, the other two are taken to 
+be a filename.  A GLOB-ref is a filehandle, the other two are taken to
 be literal content.
 
 =cut
@@ -330,7 +351,7 @@ sub patch_multi {
         chomp( @patches = <PATCHES> );
         $self->{pfinfo} ||= 'file content';
     } else {
-        my $full_name = File::Spec->file_name_is_absolute( $pfile ) 
+        my $full_name = File::Spec->file_name_is_absolute( $pfile )
             ? $pfile : File::Spec->rel2abs( $pfile, $self->{pdir} );
         $self->{pfinfo} = $full_name;
         open PATCHES, "< $full_name" or do {
@@ -386,7 +407,7 @@ sub _make_opts {
 
 =item $patcher->call_patch( $ref_to_content )
 
-C<call_patch()> opens a pipe to the B<patch> program and prints 
+C<call_patch()> opens a pipe to the B<patch> program and prints
 C<< $$ref_to_content >> to it. It will Carp::croak() on any error!
 
 =cut
@@ -407,7 +428,7 @@ sub call_patch {
     };
 
     # patch is verbose enough if $self->{v} == 1
-    $self->{v} > 1 and 
+    $self->{v} > 1 and
         print "[$self->{pfinfo}] | $self->{patchbin} $opts $redir\n";
 
     if ( open PATCHBIN, "| $self->{patchbin} $opts $redir" ) {
