@@ -2,6 +2,8 @@ package Test::Smoke::Poster::Curl;
 use warnings;
 use strict;
 
+our $VERSION = '0.001';
+
 use base 'Test::Smoke::Poster::Base';
 
 use CGI::Util ();                # escape() for HTML
@@ -58,6 +60,16 @@ sub _post_data {
         '-d' => $form_data,
         $self->smokedb_url,
     );
+
+    if ($self->curl->exitcode) {
+        $self->log_warn("[POST] curl exitcode: %d", $self->curl->exitcode);
+        die sprintf(
+            "POST to '%s' curl failed: %d\n",
+            $self->smokedb_url,
+            $self->curl->exitcode
+        );
+    }
+
     $self->log_debug("[CoreSmokeDB] %s", $response);
 
     return $response;
